@@ -86,7 +86,7 @@ def _load_vars_from_path(path, results, vault_password=None):
     if stat.S_ISDIR(pathstat.st_mode):
 
         # support organizing variables across multiple files in a directory
-        return True, _load_vars_from_folder(path, results)
+        return True, _load_vars_from_folder(path, results, vault_password=vault_password)
 
     # regular file
     elif stat.S_ISREG(pathstat.st_mode):
@@ -105,7 +105,7 @@ def _load_vars_from_path(path, results, vault_password=None):
         raise errors.AnsibleError("Expected a variable file or directory "
             "but found a non-file object at path %s" % (path, ))
 
-def _load_vars_from_folder(folder_path, results):
+def _load_vars_from_folder(folder_path, results, vault_password=None):
     """
     Load all variables within a folder recursively.
     """
@@ -123,9 +123,10 @@ def _load_vars_from_folder(folder_path, results):
     # filesystem lists them.
     names.sort() 
 
-    paths = [os.path.join(folder_path, name) for name in names]
+    # do not parse hidden files or dirs, e.g. .svn/
+    paths = [os.path.join(folder_path, name) for name in names if not name.startswith('.')]
     for path in paths:
-        _found, results = _load_vars_from_path(path, results)
+        _found, results = _load_vars_from_path(path, results, vault_password=vault_password)
     return results
 
             
