@@ -703,8 +703,13 @@ class TestUtils(unittest.TestCase):
         _test_combo(
             # in memory of neighbors cat
             'a {% if x %} y {%else %} {{meow}} {% endif %} cookiechip\ndone',
-            # turning \n into a split point here seems a little off.  We'll see if other tests care.
-            ['a', '{% if x %}', 'y', '{%else %}', '{{meow}}', '{% endif %}', 'cookiechip', 'done']
+            ['a', '{% if x %}', 'y', '{%else %}', '{{meow}}', '{% endif %}', 'cookiechip\ndone']
+        )
+
+        # test space preservation within quotes
+        _test_combo(
+            'content="1 2  3   4    "  foo=bar',
+            ['content="1 2  3   4    "', 'foo=bar']
         )
 
         # invalid jinja2 nesting detection
